==> nextcloud-app-calendar-1.6.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sk.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendár",
    "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
    "Open »%s«" : "Otvoriť »%s«",
    "Cheers!" : "Pekný deň!",
    "Recipient" : "Prijímateľ",
    "Too many redirects. Aborting ..." : "Príliš veľa presmerovaní. Ruším ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdialený server neposkytol prístup ku kalendáru (HTTP chyba {%s})",
    "Error connecting to remote server" : "Chyba pri pripájaní na vzdialený server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Chyba pri vyžiadaní zdrojov zo vzdialeného servera. To može súvisieť s nesprávnym certifikátom.",
    "Error requesting resource on remote server" : "Chyba pri vyžadovaní zdroja zo vzdialeného servera",
    "Individual" : "Individuálny",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Miestnosť",
    "Unknown" : "Neznámy",
    "Required" : "Vyžadovaný",
    "Optional" : "Voliteľný",
    "Does not attend" : "Nezúčastní sa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ste v neznámej časovej zóne ({tz}), používa sa UTC",
    "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
    "New event" : "Nová udalosť",
    "CalDAV address for clients" : "CalDAV adresa pre klientov",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektoré udalosti v tomto kalendári sú poškodené. Pre viac informácií skontrolujte prosím JS konzolu.",
    "Share Calendar" : "Sprístupniť kalendár",
    "Shared" : "Sprístupnené",
    "WebDAV address for subscriptions" : "WebDAV adresa pre odbery",
    "Email sent." : "Email odoslaný.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Pripomienky",
    "Repeating" : "Opakovanie",
    "When shared show full event" : "Zobraziť úplnú udalosť, ak je sprístupnená",
    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť sprístupnená",
    "When shared hide this event" : "Skryť udalosť, ak je sprístupnená",
    "Confirmed" : "Potvrdené",
    "Tentative" : "Neistý",
    "Cancelled" : "Zrušené",
    "Please add a title." : "Prosím, uveďte názov.",
    "Please select a calendar." : "Prosím, vyberte kalendár.",
    "The event can not end before it starts." : "Udalosť končí skôr ako začne!",
    "Global" : "Globálny",
    "None" : "Žiadny",
    "Every day" : "Každý deň",
    "Every week" : "Každý týždeň",
    "Every month" : "Každý mesiac",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "How about getting started by importing some calendars?" : "Čo tak začat importovaním nejakých kalendárov?",
    "At time of event" : "Pridajte čas udalosti",
    "5 minutes before" : "5 minút pred",
    "10 minutes before" : "10 minút pred",
    "15 minutes before" : "15 minút pred",
    "30 minutes before" : "30 minút pred",
    "1 hour before" : "1 hodinu pred",
    "2 hours before" : "2 hodiny pred",
    "Custom" : "Vlastný",
    "Audio" : "Zvuk",
    "Email" : "E-mail",
    "Pop-up" : "Vyskakovanie okno",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodín",
    "days" : "dni",
    "week" : "týždeň",
    "before" : "pred",
    "start" : "začiatok",
    "end" : "koniec",
    "Editing reminders of unknown type not supported." : "Editovanie pripomienky neznámeho typu nie je podporované.",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Successfully imported {imported} objects" : "Úspešne importované {imported} objekty",
    "Imported {imported} out of {all}, skipped one duplicate" : "Importované {imported} z {all}, preskočený jeden duplikát",
    "Audio alarm {time} before the event starts" : "Zvukový alarm {time} pred začiatkom udalosti",
    "Pop-up {time} before the event starts" : "Vyskakovacie okno {time} pred začiatkom udalosti",
    "Email {time} before the event starts" : "Email {time} pred začiatkom udalosti",
    "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
    "Audio alarm {time} before the event ends" : "Zvukový alarm {time} pred koncom udalosti",
    "Pop-up {time} before the event ends" : "Vyskakovacie okno {time} pred koncom udalosti",
    "Email {time} before the event ends" : "Email {time} pred koncom udalosti",
    "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
    "Audio alarm {time} after the event starts" : "Zvukový alarm {time} po začiatku udalosti",
    "Pop-up {time} after the event starts" : "Vyskakovacie okno {time} po začiatku udalosti",
    "Email {time} after the event starts" : "Email {time} po začiatku udalosti",
    "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
    "Audio alarm {time} after the event ends" : "Zvukový alarm {time} po konci udalosti",
    "Pop-up {time} after the event ends" : "Vyskakovacie okno {time} po konci udalosti",
    "Email {time} after the event ends" : "Email {time} po konci udalosti",
    "{type} {time} after the event ends" : "{type} {time} po ukončení udalosti",
    "Audio alarm at the event's start" : "Zvukový alarm pri začiatku udalosti",
    "Pop-up at the event's start" : "Vyskakovacie okno pri začiatku udalosti",
    "Email at the event's start" : "Email pri začiatku udalosti",
    "{type} at the event's start" : "{type} pri začiatku udalosti",
    "Audio alarm at the event's end" : "Zvukový alarm pri konci udalosti",
    "Pop-up at the event's end" : "Vyskakovacie okno pri konci udalosti",
    "Email at the event's end" : "Email pri konci udalosti",
    "{type} at the event's end" : "{type} pri skončení udalosti",
    "Audio alarm at {time}" : "Zvukový alarm o {time}",
    "Pop-up at {time}" : "Vyskakovacie okno o {time}",
    "Email at {time}" : "Email o {time}",
    "{type} at {time}" : "{type} o {time}",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Please enter a valid WebCal-URL" : "Zadajte prosím platnú WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Závažná chyba vo webovom proxy.  Pre viac informácií prosím kontaktujte administrátora.",
    "Title of the Event" : "Názov udalosti",
    "Starts" : "Začína",
    "Ends" : "Končí",
    "All day Event" : "Celodenná udalosť",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "More ..." : "Viac ...",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Close" : "Zavrieť",
    "Location" : "Umiestnenie",
    "Description" : "Popis",
    "Event status" : "Stav udalosti",
    "Visibility when sharing" : "Viditelnosť pri sprístupnení",
    "Export" : "Export",
    "%s has published the calendar %s" : "%s zverejnil kalendár %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chceme vás informovať, že %s zverejnil kalendár {boldstart}%s{boldend}.",
    "Click here to access it" : "Pre zobrazenie kliknite sem",
    "We wanted to inform you that %s has published the calendar %s." : "Chceme vás informovať, že %s zverejnil kalendár %s.",
    "Click on the link below to access it" : "Pre zobrazenie kliknite na odkaz nižšie",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "Today" : "Dnes",
    "More" : "Viac",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "iCal link" : "iCal odkaz",
    "Download" : "Sťahovanie",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "can edit" : "môže upraviť",
    "Share link" : "Sprístupniť odkaz",
    "Public access" : "Verejný prístup",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "New Calendar" : "Nový kalendár",
    "Name" : "Názov",
    "New Subscription" : "Nový odber",
    "Go back" : "Ísť späť",
    "Go forward" : "Ísť dopredu",
    "Calendar does not exist" : "Kalendár neexistuje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Zrejme máte nesprávny odkaz, alebo kalendár už nie je zdieľaný?",
    "Edit event" : "Upraviť udalosť",
    "Delete Event" : "Zmazať udalosť",
    "Save Event" : "Uložiť udalosť",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relatívny",
    "Absolute" : "Absolútny",
    "Repeat" : "Opakovať",
    "times every" : "krát každý",
    "Add" : "Pridať",
    "Email address of attendee" : "E-mail adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Pre pridávanie účastníkov priraďte k vašemu účtu e-mailovú adresu v osobných nastaveniach.",
    "from" : "od",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Pravidlá opakovania tejto udalosti ešte nie sú podporované.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pre rozšírené pravidlá bude pridaná v ďalších aktualizáciách.",
    "Reset repeating rule" : "Vypnúť pravidlo opakovania",
    "Repeat every ..." : "Opakovať každý ...",
    "end repeat ..." : "ukončiť opakovanie ...",
    "times" : "krát",
    "Import Calendars" : "Importovať kalendáre",
    "Import canceled" : "Import zrušený",
    "Analyzing calendar" : "Analyzujem kalendár",
    "The file contains objects incompatible with the selected calendar" : "Súbor obsahuje objekty, ktore nie sú kompatibilné so zvoleným kalendárom",
    "New calendar" : "Nový kalendár",
    "File is empty" : "Súbor je prázdny",
    "Import scheduled" : "Import naplánovaný",
    "%s shared the calendar <strong>%s</strong> with you" : "%s zdieľaných kalendárov <strong>%s</strong> s vami",
    "Embed" : "Vložiť",
    "Iframe to integrate" : "Pridať Iframe",
    "Publish URL" : "Zverejniť URL",
    "Settings & import" : "Nastavenia a import",
    "Import calendar" : "Importovať kalendár",
    "No Calendars selected for import" : "Nebol označený kalendár na import",
    "Skip simple event editor" : "Nepoužívať jednoduchý editor",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Primary CalDAV address" : "Primárna CalDAV adresa",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa",
    "Subscribe" : "Odoberať"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-app-calendar-1.6.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sk.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendár",
    "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
    "Open »%s«" : "Otvoriť »%s«",
    "Cheers!" : "Pekný deň!",
    "Recipient" : "Prijímateľ",
    "Too many redirects. Aborting ..." : "Príliš veľa presmerovaní. Ruším ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdialený server neposkytol prístup ku kalendáru (HTTP chyba {%s})",
    "Error connecting to remote server" : "Chyba pri pripájaní na vzdialený server",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Chyba pri vyžiadaní zdrojov zo vzdialeného servera. To može súvisieť s nesprávnym certifikátom.",
    "Error requesting resource on remote server" : "Chyba pri vyžadovaní zdroja zo vzdialeného servera",
    "Individual" : "Individuálny",
    "Group" : "Skupina",
    "Resource" : "Zdroj",
    "Room" : "Miestnosť",
    "Unknown" : "Neznámy",
    "Required" : "Vyžadovaný",
    "Optional" : "Voliteľný",
    "Does not attend" : "Nezúčastní sa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ste v neznámej časovej zóne ({tz}), používa sa UTC",
    "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
    "New event" : "Nová udalosť",
    "CalDAV address for clients" : "CalDAV adresa pre klientov",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektoré udalosti v tomto kalendári sú poškodené. Pre viac informácií skontrolujte prosím JS konzolu.",
    "Share Calendar" : "Sprístupniť kalendár",
    "Shared" : "Sprístupnené",
    "Could not save WebCal-calendar" : "Nepodarilo sa uložiť WebCal-kalendár",
    "WebDAV address for subscriptions" : "WebDAV adresa pre odbery",
    "Email sent." : "Email odoslaný.",
    "Could not send your email." : "Nepodarilo sa odoslať váš email.",
    "group" : "skupina",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Pripomienky",
    "Repeating" : "Opakovanie",
    "When shared show full event" : "Zobraziť úplnú udalosť, ak je sprístupnená",
    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť sprístupnená",
    "When shared hide this event" : "Skryť udalosť, ak je sprístupnená",
    "Confirmed" : "Potvrdené",
    "Tentative" : "Neistý",
    "Cancelled" : "Zrušené",
    "Please add a title." : "Prosím, uveďte názov.",
    "Please select a calendar." : "Prosím, vyberte kalendár.",
    "The event can not end before it starts." : "Udalosť končí skôr ako začne!",
    "Global" : "Globálny",
    "None" : "Žiadny",
    "Every day" : "Každý deň",
    "Every week" : "Každý týždeň",
    "Every month" : "Každý mesiac",
    "Every year" : "Každý rok",
    "never" : "nikdy",
    "after" : "po",
    "Automatic ({timezone})" : "Automatická ({timezone})",
    "How about getting started by importing some calendars?" : "Čo tak začat importovaním nejakých kalendárov?",
    "At time of event" : "Pridajte čas udalosti",
    "5 minutes before" : "5 minút pred",
    "10 minutes before" : "10 minút pred",
    "15 minutes before" : "15 minút pred",
    "30 minutes before" : "30 minút pred",
    "1 hour before" : "1 hodinu pred",
    "2 hours before" : "2 hodiny pred",
    "Custom" : "Vlastný",
    "Audio" : "Zvuk",
    "Email" : "E-mail",
    "Pop-up" : "Vyskakovanie okno",
    "sec" : "sek",
    "min" : "min",
    "hours" : "hodín",
    "days" : "dni",
    "week" : "týždeň",
    "before" : "pred",
    "start" : "začiatok",
    "end" : "koniec",
    "Editing reminders of unknown type not supported." : "Editovanie pripomienky neznámeho typu nie je podporované.",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Successfully imported {imported} objects" : "Úspešne naimportované položky: {imported}",
    "Imported {imported} out of {all}, skipped one duplicate" : "Úspešne naimportované položky: {imported} z {all}, preskočená jedna duplicita",
    "Imported {imported} out of {all}, one failure" : "Úspešne naimportované položky: {imported} z {all}, jedna chyba",
    "Imported {imported} out of {all}, {errors} failures" : "Úspešne naimportované položky: {imported} z {all}, chyby: {errors}",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Úspešne naimportované položky: {imported} z {all}, preskočených duplicít: {duplicates}",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Úspešne naimportované položky: {imported} z {all}, chyby: {errors}, preskočených duplicít: {duplicates}",
    "Audio alarm {time} before the event starts" : "Zvukový alarm {time} pred začiatkom udalosti",
    "Pop-up {time} before the event starts" : "Vyskakovacie okno {time} pred začiatkom udalosti",
    "Email {time} before the event starts" : "Email {time} pred začiatkom udalosti",
    "None {time} before the event starts" : "Žiadna, {zime} pred začiatkom udalosti",
    "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
    "Audio alarm {time} before the event ends" : "Zvukový alarm {time} pred koncom udalosti",
    "Pop-up {time} before the event ends" : "Vyskakovacie okno {time} pred koncom udalosti",
    "Email {time} before the event ends" : "Email {time} pred koncom udalosti",
    "None {time} before the event ends" : "Email {time} pred koncom udalosti ",
    "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
    "Audio alarm {time} after the event starts" : "Zvukový alarm {time} po začiatku udalosti",
    "Pop-up {time} after the event starts" : "Vyskakovacie okno {time} po začiatku udalosti",
    "Email {time} after the event starts" : "Email {time} po začiatku udalosti",
    "None {time} after the event starts" : "Žiadna {time} po začiatku udalosti ",
    "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
    "Audio alarm {time} after the event ends" : "Zvukový alarm {time} po konci udalosti",
    "Pop-up {time} after the event ends" : "Vyskakovacie okno {time} po konci udalosti",
    "Email {time} after the event ends" : "Email {time} po konci udalosti",
    "None {time} after the event ends" : "Žiadna {time} po ukončení udalosti ",
    "{type} {time} after the event ends" : "{type} {time} po ukončení udalosti",
    "Audio alarm at the event's start" : "Zvukový alarm pri začiatku udalosti",
    "Pop-up at the event's start" : "Vyskakovacie okno pri začiatku udalosti",
    "Email at the event's start" : "Email pri začiatku udalosti",
    "None at the event's start" : "Žiadna pri začiatku udalosti ",
    "{type} at the event's start" : "{type} pri začiatku udalosti",
    "Audio alarm at the event's end" : "Zvukový alarm pri konci udalosti",
    "Pop-up at the event's end" : "Vyskakovacie okno pri konci udalosti",
    "Email at the event's end" : "Email pri konci udalosti",
    "None at the event's end" : "Žiadna pri skončení udalosti ",
    "{type} at the event's end" : "{type} pri skončení udalosti",
    "Audio alarm at {time}" : "Zvukové upozornienie, {time}",
    "Pop-up at {time}" : "Vyskakovacie okno, {time}",
    "Email at {time}" : "Email, {time}",
    "None at {time}" : "Žiadna, {time}",
    "{type} at {time}" : "{type}, {time}",
    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
    "Please enter a valid WebCal-URL" : "Zadajte prosím platnú WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Závažná chyba vo webovom proxy.  Pre viac informácií prosím kontaktujte administrátora.",
    "A Calendar app for Nextcloud" : "Aplikácia Kalendár pre Nextcloud",
    "Title of the Event" : "Názov udalosti",
    "Starts" : "Začína",
    "Ends" : "Končí",
    "All day Event" : "Celodenná udalosť",
    "Delete" : "Zmazať",
    "Cancel" : "Zrušiť",
    "More ..." : "Viac ...",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Close" : "Zavrieť",
    "Location" : "Umiestnenie",
    "Description" : "Popis",
    "Event status" : "Stav udalosti",
    "Visibility when sharing" : "Viditelnosť pri sprístupnení",
    "Export" : "Export",
    "%s has published the calendar %s" : "%s zverejnil kalendár %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chceme vás informovať, že %s zverejnil kalendár {boldstart}%s{boldend}.",
    "Click here to access it" : "Pre zobrazenie kliknite sem",
    "We wanted to inform you that %s has published the calendar %s." : "Chceme vás informovať, že %s zverejnil kalendár %s.",
    "Click on the link below to access it" : "Pre zobrazenie kliknite na odkaz nižšie",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "Today" : "Dnes",
    "More" : "Viac",
    "Edit" : "Upraviť",
    "Link" : "Odkaz",
    "iCal link" : "iCal odkaz",
    "Download" : "Sťahovanie",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "can edit" : "môže upraviť",
    "Share link" : "Sprístupniť odkaz",
    "Public access" : "Verejný prístup",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "New Calendar" : "Nový kalendár",
    "Name" : "Názov",
    "New Subscription" : "Nový odber",
    "Go back" : "Ísť späť",
    "Go forward" : "Ísť dopredu",
    "Calendar does not exist" : "Kalendár neexistuje",
    "Maybe you got a wrong link or the calendar was unshared?" : "Zrejme máte nesprávny odkaz, alebo kalendár už nie je zdieľaný?",
    "Edit event" : "Upraviť udalosť",
    "Delete Event" : "Zmazať udalosť",
    "Save Event" : "Uložiť udalosť",
    "Time" : "Čas",
    "Type" : "Typ",
    "Relative" : "Relatívny",
    "Absolute" : "Absolútny",
    "Repeat" : "Opakovať",
    "times every" : "krát každý",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Notifikácie emailom ešte nie sú v rámci CalDAV serveru implementované, nebudú odosielané.",
    "Add" : "Pridať",
    "Email address of attendee" : "E-mail adresa účastníka",
    "Please add your email address in the personal settings in order to add attendees." : "Pre pridávanie účastníkov priraďte k vašemu účtu e-mailovú adresu v osobných nastaveniach.",
    "from" : "od",
    "to" : "do",
    "This event's repeating rule is not supported yet." : "Pravidlá opakovania tejto udalosti ešte nie sú podporované.",
    "Support for advanced rules will be added with subsequent updates." : "Podpora pre rozšírené pravidlá bude pridaná v ďalších aktualizáciách.",
    "Reset repeating rule" : "Vypnúť pravidlo opakovania",
    "Repeat every ..." : "Opakovať každý ...",
    "end repeat ..." : "ukončiť opakovanie ...",
    "times" : "krát",
    "Import Calendars" : "Importovať kalendáre",
    "Import canceled" : "Import zrušený",
    "Analyzing calendar" : "Analyzujem kalendár",
    "The file contains objects incompatible with the selected calendar" : "Súbor obsahuje objekty, ktore nie sú kompatibilné so zvoleným kalendárom",
    "New calendar" : "Nový kalendár",
    "File is empty" : "Súbor je prázdny",
    "File could not be parsed" : "Súbor nie je čitateľný",
    "Import scheduled" : "Import naplánovaný",
    "%s shared the calendar <strong>%s</strong> with you" : "%s zdieľaných kalendárov <strong>%s</strong> s vami",
    "Embed" : "Vložiť",
    "Iframe to integrate" : "Pridať Iframe",
    "Publish URL" : "Zverejniť URL",
    "Settings & import" : "Nastavenia a import",
    "Import calendar" : "Importovať kalendár",
    "No Calendars selected for import" : "Nebol označený kalendár na import",
    "Skip simple event editor" : "Nepoužívať jednoduchý editor",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Timezone" : "Časová zóna",
    "Primary CalDAV address" : "Primárna CalDAV adresa",
    "iOS/macOS CalDAV address" : "iOS/macOS CalDAV adresa",
    "Subscribe" : "Odoberať"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
